import 'dart:async';
import 'dart:convert';
import 'dart:io';
import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';

typedef OnPlatformViewCreatedCallback = void Function(
    AndroidViewController controller);


class BlurViewWidget extends StatefulWidget {
  final OnPlatformViewCreatedCallback onBlurViewWidgetCreated;
  final String type;

  const BlurViewWidget({
    Key? key,
    required this.onBlurViewWidgetCreated,
    required this.type,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _BlurViewWidgetState();
}

class _BlurViewWidgetState extends State<BlurViewWidget> {
  @override
  Widget build(BuildContext context) {
    const String viewType = 'plugins/blur_view_widget';
    return SizedBox(
        height: (widget.type == '0' || widget.type == '1' ||
            widget.type == '2' || widget.type == '7' ||
            widget.type == '8') ? 350 : 150,
        child: Platform.isAndroid ? AndroidView(
          viewType: 'plugins/blur_view_widget',
          creationParams: {
            'type': widget.type
          },
          creationParamsCodec: StandardMessageCodec(),
          onPlatformViewCreated: _onPlatformViewCreated,
        ) : UiKitView(
          viewType: 'plugins/blur_view_widget',
          creationParams: {
            'type': widget.type
          },
          onPlatformViewCreated: _onPlatformViewCreated,
          creationParamsCodec: const StandardMessageCodec(),
        ));


    return const Text('iOS platform version is not implemented yet.');
  }

  void _onPlatformViewCreated(int id) {
    if (widget.onBlurViewWidgetCreated == null) {
      return;
    }
    widget.onBlurViewWidgetCreated(AndroidViewController._(id));
  }
}

class AndroidViewController {
  AndroidViewController._(int id)
      : _channel = MethodChannel('plugins/blur_view_widget_$id');
  final MethodChannel _channel;
}
